componenttools.report_component_format_contributions
====================================================

.. autofunction:: abjad.tools.componenttools.report_component_format_contributions.report_component_format_contributions
